==> MCU_EM_xMW_60.5.000.055.zip: resources/www/user.js <==
/*
*	Script for show and edit indexes and subindexes, which included in eds file.
*   Usage: <div index="2081:1" class="tag"></div>
* 	Nedeed scripts:
*		<script src="external/jquery/jquery.js"></script>
		<script src="external/validation/jquery.validate.js"></script>
		<script src="get_set_value_tool.js"></script>
		<script src="data_type_json.js"></script>
		<script src="eds_json.js.gz" charset="utf-8"></script>
*/

(function(exports) {
	var item_data = [];
	var start;
	var eds_object_array = [];
	//var eds_object;

	/*exports.include = function(url) {
        var script = document.createElement('script');
        script.src = url;
        document.getElementsByTagName('head')[0].appendChild(script);
    }*/

	exports.parse_page = function()
	{
		get_set_value.set_eds_object();

		start = new Date()

		//console.log(eds_object["index_list"])
		$(".tag").each(function(tag_index, tag_item) {
			//console.log(`tag_index:${$(tag_item).attr('index')}`)
			index_arr = $(tag_item).attr('index').split(':')
			//console.log(index_arr)
			if (index_arr[0] != "" && index_arr[1] != "")
			{
				if (eds_object[index_arr[0]] != undefined)
				{
					//console.log(eds_object[index_arr[0]])
					//console.log(eds_object['index_list'][index_arr[0]][$(tag_item).attr('index')])
					item_data[tag_index] = eds_object[index_arr[0]].subs[index_arr[1]];
				}
			}
		})

		var end  = new Date();
		var time = end.getTime() - start.getTime();
		console.log('Timer finished in', time, 'ms');

		
		get_set_value.set_request_data(item_data);
		get_set_value.send_query();
	
		$(".tag").each(function(tag_index, tag_item) {
			var class_type = ""
			if ($(tag_item).hasClass("ro"))
			{
				class_type = "ro"
			}
			//console.log(`tag_index2:${tag_index}`)
			var cell = get_set_value.get_cell(tag_index, class_type)
			$(tag_item).append(cell)
		});

		l100n.localize_all_pages()
	}
})(this.user = {});

==> MCU_EM_xMW_60.5.000.135.zip: resources/www/user.js <==
/*
*	Script for show and edit indexes and subindexes, which included in eds file.
*   Usage: <div index="2081:1" class="tag"></div>
* 	Nedeed scripts:
*		<script src="external/jquery/jquery.js"></script>
		<script src="external/validation/jquery.validate.js"></script>
		<script src="get_set_value_tool.js"></script>
		<script src="eds_json.js.gz" charset="utf-8"></script>
*/

(function(exports) {
	var item_data = [];
	var start;
	var eds_object_array = [];
	//var eds_object;

	/*exports.include = function(url) {
        var script = document.createElement('script');
        script.src = url;
        document.getElementsByTagName('head')[0].appendChild(script);
    }*/

	exports.parse_page = function()
	{
		get_set_value.set_eds_object();

		start = new Date()

		//console.log(eds_object["index_list"])
		$(".tag").each(function(tag_index, tag_item) {
			//console.log(`tag_index:${$(tag_item).attr('index')}`)
			index_arr = $(tag_item).attr('index').split(':')
			//console.log(index_arr)
			if (index_arr[0] != "" && index_arr[1] != "")
			{
				if (eds_object[index_arr[0]] != undefined)
				{
					//console.log(eds_object[index_arr[0]])
					//console.log(eds_object['index_list'][index_arr[0]][$(tag_item).attr('index')])
					item_data[tag_index] = eds_object[index_arr[0]].subs[index_arr[1]];
				}
				else
				{
					console.log(`Index: 0x${index_arr[0]}_${index_arr[1]} is absent in eds file`)
				}
			}
		})

		var end  = new Date();
		var time = end.getTime() - start.getTime();
		console.log('Timer finished in', time, 'ms');

		get_set_value.set_request_data(item_data);
		get_set_value.send_query();
	
		$(".tag").each(function(tag_index, tag_item) {
			var class_type = ""
			if ($(tag_item).hasClass("ro"))
			{
				class_type = "ro"
			}
			else if ($(tag_item).hasClass("boolean_input"))
			{
				class_type = "boolean_input"
			}
			else if ($(tag_item).hasClass("boolean_output"))
			{
				class_type = "boolean_output"
			}
			else if ($(tag_item).hasClass("boolean_alarm"))
			{
				class_type = "boolean_alarm"
			}
			//console.log(`tag_index2:${tag_index}`)
			var cell = get_set_value.get_cell(tag_index, class_type)
			$(tag_item).append(cell)
		});

		l100n.localize_all_pages()
	}
})(this.user = {});
